==> igniteui-react-charts-16.6.8.tgz: package/ES2015/ChaikinVolatilityIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ChaikinVolatilityIndicatorStrategy } from "./ChaikinVolatilityIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class ChaikinVolatilityIndicator extends StrategyBasedIndicator {
    get_p5() {
        return new ChaikinVolatilityIndicatorStrategy();
    }
    get p5() {
        return this.get_p5();
    }
    get_qi() {
        return ChaikinVolatilityIndicator.$;
    }
    get qi() {
        return this.get_qi();
    }
    get qq() {
        return typeGetValue(this.c(ChaikinVolatilityIndicator.qr));
    }
    set qq(a) {
        this.h(ChaikinVolatilityIndicator.qr, a);
    }
    qb() {
        return this.qq;
    }
    qk(a) {
        this.qq = a;
    }
}
ChaikinVolatilityIndicator.$t = markType(ChaikinVolatilityIndicator, 'ChaikinVolatilityIndicator', StrategyBasedIndicator.$);
ChaikinVolatilityIndicator.qr = StrategyBasedIndicator.qn(10, ChaikinVolatilityIndicator.$);

==> igniteui-react-charts-16.11.1.tgz: package/ES2015/ChaikinVolatilityIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ChaikinVolatilityIndicatorStrategy } from "./ChaikinVolatilityIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class ChaikinVolatilityIndicator extends StrategyBasedIndicator {
    get_qc() {
        return new ChaikinVolatilityIndicatorStrategy();
    }
    get qc() {
        return this.get_qc();
    }
    get_qp() {
        return ChaikinVolatilityIndicator.$;
    }
    get qp() {
        return this.get_qp();
    }
    get qx() {
        return typeGetValue(this.c(ChaikinVolatilityIndicator.qy));
    }
    set qx(a) {
        this.h(ChaikinVolatilityIndicator.qy, a);
    }
    qi() {
        return this.qx;
    }
    qr(a) {
        this.qx = a;
    }
}
ChaikinVolatilityIndicator.$t = markType(ChaikinVolatilityIndicator, 'ChaikinVolatilityIndicator', StrategyBasedIndicator.$);
ChaikinVolatilityIndicator.qy = StrategyBasedIndicator.qu(10, ChaikinVolatilityIndicator.$);
